@@ -1,5 +1,5 @@
 import io
-from typing import Any
+from typing import Any, BinaryIO, Optional
 
 from .model import EHentaiResponse
 from .network import HandOver
@@ -18,18 +18,25 @@ class EHentai(HandOver):
         self.similar: bool = similar
         self.exp: bool = exp
 
-    async def search(self, url: str, ex: bool = False) -> EHentaiResponse:
+    async def search(
+        self,
+        url: Optional[str] = None,
+        file: Optional[BinaryIO] = None,
+        ex: bool = False,
+    ) -> EHentaiResponse:
         _url = (
             "https://exhentai.org/upld/image_lookup.php"
             if ex
             else "https://upld.e-hentai.org/image_lookup.php"
         )
         data = {"f_sfile": "search"}
-        if url.startswith("http"):  # 网络url
+        if url:
             file_content = io.BytesIO((await self.get(url)).content)
             files = {"sfile": file_content}
-        else:  # 本地文件
-            files = {"sfile": open(url, "rb")}  # type: ignore
+        elif file:
+            files = {"sfile": file}  # type: ignore
+        else:
+            raise ValueError("url or file is required")
         if self.covers:
             data["fs_covers"] = "on"
         if self.similar:
